## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global svnversion 4982
%global date 20250317
%global maj_ver 4.3

Name:       skychart
Version:    %{maj_ver}^%{date}.svn%{svnversion}
Release:    %autorelease
Summary:    Planetarium software for the advanced amateur astronomer
# bgrabitmap code is licensed LGPL-3.0-only WITH LGPL-3.0-linking-exception
License:    GPL-2.0-or-later AND LGPL-3.0-only WITH LGPL-3.0-linking-exception
URL:        http://www.ap-i.net/skychart/
# Upstream sources are modified to:
# - Remove pre-built software (iridflare.exe, quicksat.exe, dll files)
# - Remove unneeded Windows and MacOS stuff
# - Remove libraries provided by libpasastro package
#   (they still are in sources only for compiling the Windows version)
# To do this we use the generate-tarball.sh script
# Download upstream tarball from
# https://sourceforge.net/projects/skychart/files/0-beta/
# in the same directory of the script and run:
# ./generate-tarball.sh 4.3-4982
Source0:    %{name}-%{maj_ver}-%{svnversion}-src-nopatents.tar.xz
Source1:    generate-tarball.sh
# Base source data
Source2:    http://sourceforge.net/projects/skychart/files/4-source_data/data_spicesun.tgz


# Avoid stripping debuginfo from executables
# This is Fedora specific and not reported upstream
Patch:      skychart-4.3-nostrip.patch

# Disable wget in install script
# This is Fedora specific and not reported upstream
Patch:      skychart-4.1-wgetdata.patch

# Notify the user that artificial satellites calculation
# has been disabled in Fedora RPMs due to Fedora policies
# This is Fedora specific and not reported upstream
Patch:      skychart-4.3-satmessage.patch

# Disable software update menu item
# This feature was asked upstream specifically for Fedora
Patch:      skychart-4.3-noupdatemenu.patch


ExclusiveArch: %{fpc_arches}
ExcludeArch: %{ix86}


BuildRequires: make
BuildRequires: fpc
BuildRequires:  fpc-src
BuildRequires:  lazarus-lcl-nogui
BuildRequires:  lazarus-lcl-qt5
BuildRequires:  lazarus-tools
BuildRequires: desktop-file-utils
BuildRequires: dos2unix
BuildRequires: gtk2-devel
BuildRequires: ImageMagick
BuildRequires: libappstream-glib

Requires: libpasastro
Requires: tzdata
Requires: xdg-utils
Requires: xplanet

Recommends: openssl-libs
# Used for binary planetary ephemeris files
Recommends: calceph-libs
# Used for Gaia catalog
Recommends: chealpix

# Weak dependency on catgen
Recommends: skychart-catgen = %{version}-%{release}

# Upstream changed the way extra catalogs are managed: they can now be
# downloaded and installed within program in the user homedir.
# Old catalogs provided as extra packages are no more valid.
Obsoletes:      skychart-data-stars < 4.3^20250317
Obsoletes:      skychart-data-dso < 4.3^20250317


%description
This program enables you to draw sky charts, making use of the data in 16
catalogs of stars and nebulae. In addition the position of planets,
asteroids and comets are shown.

The purpose of this program is to prepare different sky maps for a
particular observation. A large number of parameters help you to choose
specifically or automatically which catalogs to use, the colour and the
dimension of stars and nebulae, the representation of planets, the display
of labels and coordinate grids, the superposition of pictures, the
condition of visibility and more. All these features make this celestial
atlas more complete than a conventional planetarium.


%package doc
Summary:        Documentation files for Skychart
License:        CC-BY-SA-3.0 OR GFDL-1.3-no-invariants-or-later
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description doc
Documentation files from the official Skychart wiki provided
within the program as an offline copy.


%package catgen
Summary:        Custom catalog builder for Skychart
License:        GPL-2.0-or-later
Provides:       catgen = %{version}-%{release}

%description catgen
Custom catalog builder for Skychart.

%prep
%setup -q -n %{name}-%{maj_ver}-%{svnversion}-src

%autopatch -p1

# Fix executable bit set on sources
find skychart -type f -print0 | xargs -0 chmod -x

# Put additional catalogs files where are required for installation
cp -p %SOURCE2 ./BaseData


%build
./configure lazarus=%{_libdir}/lazarus prefix=%{_prefix}

# Skychart doesn't like parallel building so we don't use macro.
# We pass the following options to fpc compiler:
# - O2 for code optimization level
# - gw4 for generating dwarf 4 debug symbols
# - Cg to generate PIC code
make fpcopts="-O2 -gw4 -Cg"


%install
# Install main program
make install PREFIX=%{buildroot}%{_prefix}

# Install catalogs, translations and data files
make install install_data PREFIX=%{buildroot}%{_prefix}

# Install wiki documentation
make install install_doc PREFIX=%{buildroot}%{_prefix}

# Remove old extra packages metadata leftover
rm -f %{buildroot}%{_datadir}/metainfo/net.ap_i.%{name}.%{name}_data_stars.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/net.ap_i.%{name}.%{name}_data_dso.metainfo.xml


%check
# Menu entry
desktop-file-validate %{buildroot}%{_datadir}/applications/net.ap_i.*.desktop

# Appdata file check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.metainfo.xml


%files
%license skychart/gpl.txt
%doc %{_datadir}/doc/skychart/changelog
%doc %{_datadir}/doc/skychart/copyright
%{_bindir}/%{name}
%{_bindir}/cdcicon
%{_bindir}/varobs
%{_datadir}/applications/net.ap_i.%{name}.desktop
%{_datadir}/applications/net.ap_i.varobs.desktop
%{_datadir}/metainfo/net.ap_i.%{name}.metainfo.xml
%{_datadir}/metainfo/net.ap_i.varobs.metainfo.xml
%{_datadir}/mime/packages/net.ap_i.%{name}.xml
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/pixmaps/varobs.png
%{_datadir}/icons/*/*/*/%{name}.png
%{_datadir}/icons/*/*/*/varobs.png
%{_datadir}/icons/*/*/*/%{name}.svg
%{_datadir}/icons/*/*/*/varobs.svg
%dir %{_datadir}/skychart
%{_datadir}/skychart/data
%dir %{_datadir}/skychart/cat
%{_datadir}/skychart/cat/DSoutlines
%{_datadir}/skychart/cat/milkyway
%{_datadir}/skychart/cat/openngc
%{_datadir}/skychart/cat/RealSky
%{_datadir}/skychart/cat/xhip
%dir %{_datadir}/skychart/doc
%{_datadir}/skychart/doc/html_doc
%{_datadir}/skychart/doc/releasenotes*.txt
%{_datadir}/skychart/doc/varobs

%files doc
%doc %{_datadir}/skychart/doc/wiki_doc

%files catgen
%{_bindir}/catgen
%{_datadir}/applications/net.ap_i.catgen.desktop
%{_datadir}/metainfo/net.ap_i.catgen.metainfo.xml
%{_datadir}/pixmaps/catgen.png
%{_datadir}/icons/*/*/*/catgen.png
%{_datadir}/icons/*/*/*/catgen.svg


%changelog
## START: Generated by rpmautospec
* Tue Mar 18 2025 Mattia Verga <mattia.verga@proton.me> - 4.3^20250317.svn4982-1
- Uncommitted changes

* Sun Mar 09 2025 Mattia Verga <mattia.verga@proton.me> - 4.3^20250303.svn4974-1
- Update to svn4974

* Sun Jan 19 2025 Fedora Release Engineering <releng@fedoraproject.org> - 4.3^20240205.svn4719-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Aug 02 2024 Mattia Verga <mattia.verga@proton.me> - 4.3^20240205.svn4719-3
- Fix F41 FTB (Fedora#2301274)

* Sat Jul 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 4.3^20240205.svn4719-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Thu Feb 08 2024 Mattia Verga <mattia.verga@proton.me> - 4.3^20240205.svn4719-1
- Update to latest svn version

* Sat Jan 27 2024 Fedora Release Engineering <releng@fedoraproject.org> - 4.3^20231122.svn4639-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Nov 22 2023 Mattia Verga <mattia.verga@proton.me> - 4.3^20231122.svn4639-1
- Update to latest svn snapshot

* Mon Oct 02 2023 Mattia Verga <mattia.verga@proton.me> - 4.3^20230918.svn4630-1
- Update to latest snapshot

* Sun Sep 10 2023 Mattia Verga <mattia.verga@proton.me> - 4.3^20221203svn4558-4
- Migrate to SPDX license

* Sat Jul 22 2023 Fedora Release Engineering <releng@fedoraproject.org> - 4.3^20221203svn4558-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sat Jan 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 4.3^20221203svn4558-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Dec 03 2022 Mattia Verga <mattia.verga@proton.me> - 4.3^20221203svn4558-1
- Update to svn4558

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 4.3^20220411svn4486-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Apr 11 2022 Mattia Verga <mattia.verga@protonmail.com> - 4.3^20220411svn4486-1
- Update to 4.3-4486
- Add support for OpenSSL3

* Sat Feb 05 2022 Mattia Verga <mattia.verga@protonmail.com> - 4.3-10.4466svn
- Update svn version
- Provide catgen by separate standalone subpackage

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 4.3-9.4401svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Mon Nov 01 2021 Mattia Verga <mattia.verga@protonmail.com> - 4.3-8.4401svn
- Update svn version

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.3-7.4358svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sun May 02 2021 Mattia Verga <mattia.verga@protonmail.com> - 4.3-6.4358svn
- Update svn version

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.3-5.4238svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Dec 15 2020 Mattia Verga <mattia.verga@protonmail.com> - 4.3-4.4238svn
- Update svn version

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.3-3.4108svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Feb 08 2020 Mattia Verga <mattia.verga@protonmail.com> - 4.3-2.4108svn
- ExcludeArch ppc64le due to compilation errors

* Sat Feb 01 2020 Mattia Verga <mattia.verga@protonmail.com> - 4.3-1.4108svn
- Update to 4.3 svn

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.1-2.4073svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Nov 26 2019 Mattia Verga <mattia.verga@protonmail.com> - 4.2.1-1.4073svn
- Update to stable 4.2.1

* Fri Oct 18 2019 Mattia Verga <mattia.verga@protonmail.com> - 4.2-1.4046svn
- Release stable 4.2

* Thu Aug 29 2019 Mattia Verga <mattia.verga@protonmail.com> - 4.1.1-5.4000svn
- Update svn version

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.1.1-4.3925svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Apr 27 2019 Mattia Verga <mattia.verga@protonmail.com> - 4.1.1-3.3925svn
- Update svn version

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.1.1-2.3792svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Nov 03 2018 Mattia Verga <mattia.verga@protonmail.com> - 4.1.1-1.3792svn
- Update svn version

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.1-2.3730svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun Feb 25 2018 Mattia Verga <mattia.verga@email.it> - 4.1-1.3730svn
- Upgrade to development version to fix build failures

* Sun Feb 25 2018 Mattia Verga <mattia.verga@email.it> - 4.0-8
- Rebuild for fpc 3.0.4 and lazarus 1.8

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jan 18 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 4.0-6
- Remove obsolete scriptlets

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Sat Jul 29 2017 Mattia Verga <mattia.verga@email.it> - 4.0-4
- Change FPC compiler options to fix debuginfo package build

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Apr 12 2017 Mattia Verga <mattia.verga@tiscali.it> - 4.0-2
- Fix for OpenSSL 1.1

* Sun Mar 19 2017 Mattia Verga <mattia.verga@tiscali.it> - 4.0-1
- Release ver 4.0

* Sun Mar 05 2017 Mattia Verga <mattia.verga@tiscali.it> - 3.11-17.3549svn
- Patch to fix libssl and libcrypto links

* Mon Feb 27 2017 Mattia Verga <mattia.verga@tiscali.it> - 3.11-16.3549svn
- Update svn version

* Sun Feb 12 2017 Mattia Verga <mattia.verga@tiscali.it> - 3.11-15.3287svn
- Set ExcludeArch ppc64 due to lazarus limitations

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.11-14.3287svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Sep 17 2016 Mattia Verga <mattia.verga@tiscali.it> - 3.11-13.3287svn
- Update svn version

* Sun Apr 17 2016 Mattia Verga <mattia.verga@tiscali.it> - 3.11-12.3238svn
- Use new fpc_arches macro as ExclusiveArch

* Sun Apr 17 2016 Mattia Verga <mattia.verga@tiscali.it> - 3.11-11.3238svn
- Remove additional NGC catalog due to incompatible license

* Mon Feb 15 2016 Mattia Verga <mattia.verga@tiscali.it> - 3.11-10.3238svn
- Update svn version
- Remove remnants of pre built .dll files in sources
- Remove libraries from sources that are now provided externally
- Patch to inform user about artificial satellites calculation removal
- Patch to set option to disable software update menu item

* Fri Feb 12 2016 Mattia Verga <mattia.verga@tiscali.it> - 3.11-9.3229svn
- Update svn version
- FSF address in sources is now fixed upstream
- Appdata file is now fixed upstream
- Updated catalog_wds source file from upstream

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.11-8.3157svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 15 2016 Richard Hughes <richard@hughsie.com> - 3.11-7.3157svn
- Fix the metainfo files by removing zero-width space chars

* Mon Jan 11 2016 Mattia Verga <mattia.verga@tiscali.it> - 3.11-6.3157svn
- Add .metainfo.xml files to subpackages

* Sun Jan 10 2016 Mattia Verga <mattia.verga@tiscali.it> - 3.11-5.3157svn
- Update svn version
- Libraries are now in separate package libpasastro
- Fix wrong FSF address in source headers
- Fix appdata file validation

* Sun Dec 20 2015 Mattia Verga <mattia.verga@tiscali.it> - 3.11-4.3141svn
- Properly set ExcludeArch

* Fri Dec 11 2015 Mattia Verga <mattia.verga@tiscali.it> - 3.11-3.3141svn
- Revert back to ExcludeArch

* Fri Nov 27 2015 Mattia Verga <mattia.verga@tiscali.it> - 3.11-2.3141svn
- Set ExclusiveArch to prevent build on arm and s390x

* Sat Nov 14 2015 Mattia Verga <mattia.verga@tiscali.it> - 3.11-1.3141svn
- Update to 3.11svn to fix incompatibility with lazarus 1.4.2

* Sun Jun 21 2015 Mattia Verga <mattia.verga@tiscali.it> - 3.10-7
- Validate appdata file
- Change license file location

* Sat Jun 20 2015 Mattia Verga <mattia.verga@tiscali.it> - 3.10-6
- Added patch to fix build with lazarus 1.4

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.10-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.10-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Apr 03 2014 Mattia Verga <mattia.verga@tiscali.it> - 3.10-2
- Fix patch1

* Thu Apr 03 2014 Mattia Verga <mattia.verga@tiscali.it> - 3.10-1
- Update to 3.10

## END: Generated by rpmautospec
